Function language_e2e_tests::compile::compile_module[][src]

pub fn compile_module(code: &str) -> (CompiledModule, Module)
Compile the provided Move code into a blob which can be used as the code to be published (a Module).